@@ -21,3 +21,18 @@ def list_difference(list1: list, list2: list, safe: bool = True) -> list:
         return [x for x in list1 if x not in list2]
     else:
         return list(set(list1) - set(list2))
+
+
+def prod(numbers: list) -> int:
+    """Verilen listedeki tüm elemanları çarpar
+
+    Arguments:
+        numbers {list} -- Sayı listesi
+
+    Returns:
+        int -- Çarpımın sonucu
+    """
+    result = 1
+    for number in numbers:
+        result *= number
+    return result
